**Example 1: 修改设备信息**



Input: 

```
tccli iotvideo ModifyDevice --cli-unfold-argument  \
    --ProductId WYILLHRQ4 \
    --DeviceName test1 \
    --EnableState 1
```

Output: 
```
{
    "Response": {
        "RequestId": "216abff3-4465-4a70-82bd-4b98504d9fea"
    }
}
```

